==> aroundme_0_5_3.zip: aroundme_0_5_3/aroundme/language/1/barnraiser_01/node_abuse_reports.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'node_common.lang.php');

/*
* All language vars should be ordered TYPE, A-Z for convenience
* Tom Calthrop - 20th April 2004 (tom@barnraiser.org)
*/

//HEADERS
$lang['hdr_report_list'] = 						"reports";
$lang['hdr_report'] = 							"report";


//HREF
$lang['href_list_reports'] = 					"list reports";


//ERRORS
$lang['err_no_reports'] = 						"thankfully there are no abuse reports available";


//SUB BUTTONS
$lang['sub_update_report'] = 					"update";


//BODY TEXT
$lang['txt_datetime'] = 						"date";
$lang['txt_status'] = 							"status";
$lang['txt_reportee'] = 						"reporter";
$lang['txt_language'] = 						"language";
$lang['txt_report_txt'] = 						"This is an instance of abuse reported by a member of the community. You are obliged to keep their information confidential when discussing the matter with the group administrator.<p>failure to resolve a proven abuse instance is again the law (Act on Responsibility for Electronic Bulletin Boards - Swedish Code of Statutes: SFS 1998:112). If you are unsure how to process this report we recommend that you refer to the Barnraiser manual. This is available to the Barnraiser membership upon request. </p><p>If you are not a member of Barnraiser and you wish to create your own community we urge you to review the laws of your country regarding this matter. In many countries failure by you to comply will result in a fine or at worst case imprisonment.</p><p>All correspondence should be stored in the admin forum. Updating the status will automatically assign the report to you.</p>";
$lang['txt_from'] = 							"from";
$lang['txt_assigned'] = 						"assigned";
$lang['txt_abuse_note'] = 						"authors note";

?>

==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/node_abuse_reports.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');


//HEADERS
$lang['hdr_menu'] = 							"menu";
$lang['hdr_report_list'] = 						"reports";
$lang['hdr_report'] = 							"report";


//HREF
$lang['href_list_reports'] = 					"list reports";


//ERRORS
$lang['err_no_reports'] = 						"thankfully there are no abuse reports available";


//SUB BUTTONS
$lang['sub_update_report'] = 					"update";


//BODY TEXT
$lang['txt_datetime'] = 						"date";
$lang['txt_status'] = 							"status";
$lang['txt_reportee'] = 						"reporter";
$lang['txt_language'] = 						"language";
$lang['txt_report_txt'] = 						"This is an instance of abuse reported by a member of the community. You are obliged to keep their information confidential when discussing the matter with the group administrator.<p>failure to resolve a proven abuse instance is again the law (Act on Responsibility for Electronic Bulletin Boards - Swedish Code of Statutes: SFS 1998:112). If you are unsure how to process this report we recommend that you refer to the Barnraiser manual. This is available to the Barnraiser membership upon request. </p><p>If you are not a member of Barnraiser and you wish to create your own community we urge you to review the laws of your country regarding this matter. In many countries failure by you to comply will result in a fine or at worst case imprisonment.</p><p>All correspondence should be stored in the admin forum. Updating the status will automatically assign the report to you.</p>";
$lang['txt_from'] = 							"from";
$lang['txt_assigned'] = 						"assigned";
$lang['txt_abuse_note'] = 						"authors note";

?>
